from setuptools import setup

setup(name='geohash_polygon',
      version='0.1',
      description='',
      url='https://github.com/rhwang201/geohash_polygon',
      author='Richard Hwang',
      author_email='richard.hwang201@gmail.com',
      license='MIT',
      packages=['geohash_polygon'],
      zip_safe=False)
